@@ -1,7 +1,7 @@
-from gqlauth.utils import camelize
 import strawberry
+
 from gqlauth.bases.exceptions import WrongUsage
-from gqlauth.settings import gqlauth_settings
+from gqlauth.utils import camelize
 
 
 def serialize_excpected_error(errors):
@@ -45,5 +45,3 @@ class ExpectedErrorType:
         ]
     }
     """
-
-    pass
